Changelog
=========


2.3 (2015-05-02)
----------------

- Update requirements
  [gborelli]

- Remove c.geo.behavior as extra requires and include it as default
  [gborelli]


2.2 (2014-08-16)
----------------

- Updated c.geo.mapwidget to 2.1.3
  [gborelli]
- Updated version and year of collective.geo docs
  [macagua]
- Added documentation about collective.geo.usersmap
  [macagua]
- Added documentation about collective.geo.flexitopic
  [macagua]


2.1 (2014-02-26)
----------------

- Moved robot test from c.geo.behaviour
  [gborelli]


2.0 (2013-10-29)
----------------

- Added robotframework tests [gborelli]
- Added Sphinx documentation [gborelli]
- Added travis-ci configuration [gborelli]
- Added extras_requires in setup.py to use g.ceo with Dexterity
  [gborelli]

- Added buildout configuration
- Refacrtorized package structure
  [giacomos]



0.1 (2011-03-06)
----------------

- First release
